# -*- coding: utf-8 -*-
# sessel.py
"""Demo mit Klasse Schritte"""

from schritte import Schritte

from grafikfenster import *
from moebel import Moebel  ## Erweiterung

### ---------------------------------------------------
class Sessel(Moebel):  ## Erweiterung
    """Klasse Sessel
    ermoeglicht das Zeichnen und Bearbeiten eines
    Sessel-Symbols fuer den Raumplaner"""
    
    def __init__(self,
                 xPos=200,
                 yPos=200,
                 breite=60,
                 tiefe=60,
                 winkel=0,
                 farbe="brown",
                 sichtbar=False):
        Moebel.__init__(self,xPos,yPos,breite,tiefe,winkel,farbe,sichtbar)
        
    def GibFigur(self):
        """Definiert die zu zeichnende Figur"""
        gc = Zeichenflaeche.GibZeichenflaeche().GibGC()
        path = gc.CreatePath()

        # Hilfsvariable zur Vereinfachung
        b,t=self.GibBreite(),self.GibTiefe()
        # Umrandung
        path.MoveToPoint(0, 0)
        path.AddLineToPoint(b, 0)
        path.AddLineToPoint(b, t)
        path.AddLineToPoint(0, t)
        path.AddLineToPoint(0, 0)
        # linke Lehne
        path.MoveToPoint(b/6, 0)
        path.AddLineToPoint(b/6, t)
        # rechte Lehne
        path.MoveToPoint(5*b/6, 0)
        path.AddLineToPoint(5*b/6, t)
        # Rueck-Lehne
        path.MoveToPoint(b/6, t/6)
        path.AddLineToPoint(5*b/6, t/6)
        
        return self.Transformiere(path)

### ---------------------------------------------------
class SesselApp(wx.App):
    """Test-Anwendung speziell fuer Sessel"""
    def OnInit(self):
        self.fenster = GrafikFenster(None, "Raumplaner-Grafik")
        self.SetTopWindow(self.fenster)
        self.fenster.Show(True)
        self.fenster.panel.Refresh()
        self.fenster.ZeigeShellFrame()
        self.TestAnwendung()
        #self.fenster.ZeigeFillingFrame()
        return True

    def TestAnwendung(self):
        """Allein fuer die Testanwendung:"""
        global sessel
        print(__doc__)
        print('global: Sessel')
        self.sessel=Sessel(sichtbar=True)
        self.Schrittweise()

    def SchrittProzedur(self):
        '''definiert, was in jedem Schritt zu tun ist'''
        self.sessel.Drehe(2)
        self.sessel.BewegeVertikal(-5)

    def Schrittweise(self):
        '''verwendet die eigenstaendige Klasse Schritte'''
        self.schritte=Schritte(self, 30, self.SchrittProzedur)
        self.schritte.Start(100)

### ---------------------------------------------------
if __name__ == '__main__':
    app = SesselApp(redirect=False)
    # Parameterwert True, wenn Ausgaben in der Standard E/A angezeigt werden sollen
    app.MainLoop()
